@@ -1,14 +1,23 @@
 from typing import Optional
 
-import pkg_resources
 import typer
 
+import mapaction.modules.templates.templates
+from mapaction.libs.version import getLatestPyPiVersion
+from mapaction.libs.version import getVerison
+
 app = typer.Typer()
+app.add_typer(
+    mapaction.modules.templates.templates.app,
+    name="templates",
+    help="Utils for managing the templates"
+)
 
 
 def _version_callback(value: bool) -> None:
     if value:
-        typer.echo(pkg_resources.get_distribution("mapaction"))
+        __version__ = getVerison()
+        typer.echo(f"v{__version__}")
         raise typer.Exit()
 
 
@@ -22,11 +31,12 @@ def main(
         callback=_version_callback,
         is_eager=True,
     )
+
 ) -> None:
     return
 
 
 def run() -> None:
     """Run commands."""
-    print("--- test ---")
+    getLatestPyPiVersion()
     app()
